MethodChannelUrovoPos class

Default Android method-channel implementation for UrovoPosPlatform.

Inheritance

Constructors

MethodChannelUrovoPos()
Creates a method-channel backed platform implementation.

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
Underlying method channel used by this implementation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isUrovoSdkAvailable() Future<bool>
Returns whether the Urovo SDK classes exist on current runtime.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printerClose() Future<void>
Closes printer session.
override
printerGetStatus() Future<UrovoPrinterStatus>
Returns normalized printer status.
override
printerGetStatusDetail() Future<UrovoPrinterStatusDetail>
Returns detailed printer status.
override
printerInit() Future<void>
Opens printer session.
override
printerRunJob(UrovoPrintJob job) Future<void>
Runs a print job.
override
printerSetGray(int level) Future<void>
Sets printer gray level.
override
printerStartPrint() Future<void>
Starts print for queued vendor commands.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited