UrovoPosPlatform class abstract
Platform interface contract for urovo_pos.
- Inheritance
-
- Object
- PlatformInterface
- UrovoPosPlatform
- Implementers
Constructors
- UrovoPosPlatform()
- Creates a platform interface instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isUrovoSdkAvailable(
) → Future< bool> - Returns whether the Urovo SDK classes exist on current runtime.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printerClose(
) → Future< void> - Closes printer session.
-
printerGetStatus(
) → Future< UrovoPrinterStatus> - Returns normalized printer status.
-
printerGetStatusDetail(
) → Future< UrovoPrinterStatusDetail> - Returns detailed printer status.
-
printerInit(
) → Future< void> - Opens printer session.
-
printerRunJob(
UrovoPrintJob job) → Future< void> - Runs a print job.
-
printerSetGray(
int level) → Future< void> - Sets printer gray level.
-
printerStartPrint(
) → Future< void> - Starts print for queued vendor commands.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ UrovoPosPlatform
-
Active platform implementation.
getter/setter pair